@@ -167,14 +167,23 @@ class Framework {
 
 						$msg .= "<br />\n";
 						$msg .= $this->contentPage->translateMessageTag('fw_error_entitlement_unset_3');
-						$msg .= "<br /><ul>\n<li>";
+						$msg .= '<br /><ul><li style="margin: 1em 0 0 2em">';
 
 						$msg .= $this->contentPage->translateMessageTag('fw_error_entitlement_unset_4');
-						$msg .= "<a href=\"mailto:$email\">$email</a></li>\n<li>";
+						$msg .= "<a href=\"mailto:$email\">$email</a></li>";
+						$msg .= '<li style="margin: 1em 0 0 2em">';
 						$msg .= $this->contentPage->translateMessageTag('fw_error_entitlement_unset_5');
 						$msg .= "<a href=\"$url\">$url</a></li>\n</ul><br />\n";
 					}
 					Framework::error_output($msg);
+				} else {
+					$entitlement = Config::get_config('entitlement_namespace') . ":";
+					$entitlement = Config::get_config('entitlement_user');
+					$msg = $this->contentPage->translateMessageTag('fw_error_entitlement_unset_1');
+					$msg .= "<br /><i>$entitlement</i><br /><br />";
+					$msg .= $this->contentPage->translateMessageTag('fw_error_entitlement_unset_6');
+
+					Framework::warning_output($msg);
 				}
 			}
 		} else {
@@ -196,6 +205,11 @@ class Framework {
 	 * Some actions are more sensitive than others. This function will
 	 * notify the framework that the user should be AuthN recently. The
 	 * limit is configurable.
+	 *
+	 * @param	void
+	 * @return	void
+	 * @access	public
+	 * @static
 	 */
 	public static function sensitive_action()
 	{
@@ -290,6 +304,7 @@ class Framework {
 			$this->person->setMode($new_mode);
 		}
 
+		$this->tpl->assign('title_logo', $this->contentPage->translateMessageTag('l10n_title_logo'));
 		$this->tpl->assign('person',	$this->person);
 		$this->tpl->assign('subscriber',$this->person->getSubscriber());
 		$this->tpl->assign('nren',	$this->person->getNREN());
@@ -401,12 +416,12 @@ class Framework {
 			$customPortalTitle = $nren->getCustomPortalTitle();
 
 			if (isset($customPortalTitle)) {
-				$this->tpl->assign('system_title', $customPortalTitle);
+				$this->tpl->assign('system_title', '&nbsp;' .  $customPortalTitle);
 			} else {
-				$this->tpl->assign('system_title', Config::get_config('system_title'));
+				$this->tpl->assign('system_title', '&nbsp;' .  Config::get_config('system_title'));
 			}
 		} else {
-			$this->tpl->assign('system_title', '&nbsp;');
+			$this->tpl->assign('system_title', '');
 		}
 	} /* end applyNRENBranding */
 
@@ -531,3 +546,5 @@ class Framework {
 	} /* end validateACSRFT() */
 
 } /* end class Framework */
+
+?>
\ No newline at end of file
