@@ -495,45 +495,49 @@ class CP_Admin extends Content_Page
 	/**
 	 * downgradeNRENAdmin() Downgrade a NREN admin to the status of a subscriber admin
 	 *
-	 * @param $admin	The admin that should be downgraded to subscriber level
-	 * @param $subscriberID integer	The ID of the subscriber of which the admin is to become
-	 *			admin.
-	 *
+	 * @param  $admin_uid		String  The UID of the admin that should be downgraded.
+	 * @param  $subscriber_id	Int	ID of subscriber in the database.
 	 * @return void
+	 * @access private
 	 */
-	private function downgradeNRENAdmin($admin, $subscriberID)
+	private function downgradeNRENAdmin($admin_uid, $subscriber_id)
 	{
-		$nren = $this->person->getNREN();
-		if (empty($subscriberID)) {
-			$msg  = "Tried to downgrade NREN admin " . htmlentities($admin) . " from NREN " .
-			        htmlentities($nren) . " to subscriber admin, ";
+		if (is_null($subscriber_id)) {
+			$msg  = "Tried to downgrade NREN admin " . htmlentities($this->person->getEPPN()) . " from NREN " .
+			        htmlentities($this->person->getNREN()->getName()) . " to subscriber admin, ";
 			$msg .= "but admin's subscriber affiliaton is not set. Cannot continue.";
 			Logger::log_event(LOG_NOTICE,$msg);
 			Framework::error_output($msg);
+			return;
 		}
 
-		$query="UPDATE admins SET admin_level='1', subscriber=? WHERE admin=?";
-
 		try {
-			$res2 = MDB2Wrapper::update($query,
-										array('text','text'),
-										array($subscriberID, $admin));
+			$query  = "UPDATE admins SET admin_level='1', subscriber=:subscriber_id ";
+			$query .= "WHERE admin=:admin AND nren=:nren_id";
+			$data = array();
+			$data['subscriber_id']	= $subscriber_id;
+			$data['admin']	        = $admin_uid;
+			$data['nren_id']	= $this->person->getNREN()->getID();
+			$res = MDB2Wrapper::update($query, null, $data);
 		} catch (DBQueryException $dbqe) {
-			Framework::error_output("Problem updating your admin status. Server said: " . htmlentities($dbqe->getMessage()));
-			Logger::log_event(LOG_NOTICE, "ADMIN: Could not update admin status of admin $admin to subscriber admin " .
-							" of subscriber with ID $subscriberID");
+			Framework::error_output("Problem updating your admin status. Server said: " .
+						htmlentities($dbqe->getMessage()));
+			Logger::log_event(LOG_NOTICE, "ADMIN: Could not update admin status of admin $admin_uid to subscriber admin " .
+							" of subscriber with ID $subscriber_id");
 			return;
 		} catch (DBStatementException $dbse) {
-			Framework::error_output("Problem updating your admin status. Server said: " . htmlentities($dbse->getMessage()));
-			Logger::log_event(LOG_NOTICE, "ADMIN: Could not update admin status of admin $admin to subscriber admin " .
-							" of subscriber with ID $subscriberID");
+			Framework::error_output("Problem updating your admin status. Server said: " .
+						htmlentities($dbse->getMessage()));
+			Logger::log_event(LOG_NOTICE,
+					  "ADMIN: Could not update admin status of admin $admin_uid to subscriber admin " .
+					  " of subscriber with ID $subscriber_id");
 			return;
 		}
 
-		Logger::log_event(LOG_NOTICE, "Admin: NREN admin $admin downgraded his/her status to subscriber admin of " .
-						"subscriber with ID $subscriberID");
+		Logger::log_event(LOG_NOTICE, "Admin: NREN admin $admin_id downgraded his/her status to subscriber admin of " .
+						"subscriber with ID $subscriber_id");
 		Framework::success_output($this->translateTag('l10n_suc_downgrnren', 'admin') .
-		                          htmlentities($subscriberID));
+		                          htmlentities($subscriber_id));
 	}
 
 	/*
