@@ -1,11 +1,12 @@
 <?php
 require_once 'confusa_include.php';
-require_once 'framework.php';
-require_once 'mdb2_wrapper.php';
-require_once 'input.php';
+require_once 'Content_Page.php';
+require_once 'Framework.php';
+require_once 'MDB2Wrapper.php';
+require_once 'Input.php';
 require_once 'file_io.php';
 require_once 'file_upload.php';
-require_once 'logger.php';
+require_once 'Logger.php';
 require_once 'classTextile.php';
 require_once 'confusa_constants.php';
 
@@ -116,6 +117,20 @@ class CP_Stylist extends Content_Page
 
 				$this->deleteLogo($position, $this->person->getNREN());
 				break;
+			case 'change_title':
+				if (isset($_POST['portalTitle'])) {
+					$titleValue = Input::sanitize($_POST['portalTitle']);
+				} else {
+					$titleValue = "";
+				}
+
+				if (isset($_POST['changeButton'])) {
+					$showTitle = isset($_POST['showPortalTitle']);
+					$this->updateNRENTitle($this->person->getNREN(),
+					                       $titleValue,
+					                       $showTitle);
+				}
+				break;
 			default:
 				Framework::error_output("Unknown operation chosen in the stylist!");
 				break;
@@ -129,7 +144,7 @@ class CP_Stylist extends Content_Page
 	public function process()
 	{
 		if (!$this->person->isNRENAdmin()) {
-			Logger::log_event(LOG_NOTICE, "User " . $this->person->getX509ValidCN() . " tried to access the NREN-area");
+			Logger::log_event(LOG_NOTICE, "User " . stripslashes($this->person->getX509ValidCN()) . " tried to access the NREN-area");
 			$this->tpl->assign('reason', 'You are not an NREN-admin');
 			$this->tpl->assign('content', $this->tpl->fetch('restricted_access.tpl'));
 			return;
@@ -204,7 +219,12 @@ class CP_Stylist extends Content_Page
 					}
 				}
 				break;
-
+			case 'title':
+				$nren = $this->person->getNREN();
+				$this->tpl->assign('edit_title', true);
+				$this->tpl->assign('portalTitle', $nren->getCustomPortalTitle());
+				$this->tpl->assign('showPortalTitle', $nren->getShowPortalTitle());
+				break;
 			default:
 				Framework::error_output("Unsupported operation chosen!");
 				break;
@@ -383,6 +403,27 @@ class CP_Stylist extends Content_Page
 		Framework::success_output($this->translateTag('l10n_suc_privnoticetext', 'stylist'));
 	}
 
+	/**
+	 * Change the portal title for the given NREN to the new title, or disable
+	 * the display of a portal title.
+	 *
+	 * @param $nren NREN The NREN for which the custom portal title is set
+	 * @param $portalTitle string The custom portal-title for the NREN
+	 * @param $showPortalTitle boolean Whether a portal-title should be shown
+	 *                                 for the NREN
+	 * @return void
+	 */
+	private function updateNRENTitle($nren, $portalTitle, $showPortalTitle)
+	{
+		$nren->setCustomPortalTitle($portalTitle);
+		$nren->setShowPortalTitle($showPortalTitle);
+
+		if ($nren->saveNREN()) {
+			Framework::success_output($this->translateTag('l10n_suc_portaltitle', 'stylist') .
+			                          " $portalTitle");
+		}
+	}
+
 	/**
 	 * Fetch the CSS file content for a certain NREN. If no CSS file for the
 	 * NREN has been defined so far, display the standard site-wide CSS
@@ -440,7 +481,7 @@ class CP_Stylist extends Content_Page
 			}
 		}
 
-		$main_tpl_path = Config::get_config('install_path') . 'lib/smarty/templates/';
+		$main_tpl_path = Config::get_config('install_path') . ConfusaConstants::$SMARTY_TEMPLATES;
 		$main_tpl_path .= 'email/notification.tpl';
 
 		try {
@@ -450,11 +491,11 @@ class CP_Stylist extends Content_Page
 			Framework::error_output("Could not open Confusa's default notification " .
 			                        "mail template! Server said " .
 			                        htmlentities($fexp->getMessage()) . "!");
-			Logger::log_event(LOG_WARN, "[nadm] Could not open Confusa's default " .
-			                            "notification mail template! Server said " .
-			                            $fexp->getMessage());
+			Logger::log_event(LOG_WARNING, "[nadm] Could not open Confusa's default " .
+					  "notification mail template! Server said " .
+					  $fexp->getMessage());
 		}
-	}
+	} /* end fetchNRENMailTpl */
 
 	/*
 	 * Update the customized CSS file of a certain NREN. Write the CSS file to
@@ -538,14 +579,16 @@ class CP_Stylist extends Content_Page
 	private function sendNRENTestMail($recipient, $template)
 
 	{
-		require_once 'mail_manager.php';
+		require_once 'MailManager.php';
 		require_once 'CA.php';
 
-		$timestamp			= date('Y-m-d H:i T');
+		$timezone = new DateTimeZone($this->person->getTimezone());
+		$dt = 		new DateTime("now", $timezone);
+
 		$ip					= $_SERVER['REMOTE_ADDR'];
 		$order_number		= '1234567890 (invalid example)';
 		CA::sendMailNotification($order_number,
-		                         $timestamp,
+		                         $dt->format('Y-m-d H:i T'),
 		                         $ip,
 		                         $recipient,
 		                         $this->ca->getFullDN(),
@@ -760,7 +803,7 @@ class CP_Stylist extends Content_Page
 			Logger::log_event(LOG_INFO, "[nadm] Error when trying to delete " .
 			                  "NREN logo $logoName, for NREN $nren.");
 		}
-	}
+	} /* end function deleteLogo */
 }
 $fw = new Framework(new CP_Stylist());
 $fw->start();
